pub struct TableGroupCols(pub usize);Tuple Fields
0: usizeTrait Implementations
Sourceimpl Clone for TableGroupCols
impl Clone for TableGroupCols
Sourcefn clone(&self) -> TableGroupCols
fn clone(&self) -> TableGroupCols
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TableGroupCols
impl Debug for TableGroupCols
Sourceimpl Default for TableGroupCols
impl Default for TableGroupCols
Sourcefn default() -> TableGroupCols
fn default() -> TableGroupCols
Returns the “default value” for a type. Read more
Sourceimpl Hash for TableGroupCols
impl Hash for TableGroupCols
Sourceimpl JsonSchema for TableGroupCols
impl JsonSchema for TableGroupCols
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TableGroupCols
impl PartialEq for TableGroupCols
Sourceimpl Serialize for TableGroupCols
impl Serialize for TableGroupCols
impl Eq for TableGroupCols
impl StructuralPartialEq for TableGroupCols